@@ -106,13 +106,13 @@ void AgentManager::continueStartup()
   first = false;
 
   readPluginInfos();
-  foreach ( const AgentType &info, mAgents )
-    emit agentTypeAdded( info.identifier );
+  Q_FOREACH ( const AgentType &info, mAgents )
+    Q_EMIT agentTypeAdded( info.identifier );
 
   const QStringList pathList = pluginInfoPathList();
 
 #ifndef QT_NO_DEBUG
-  foreach ( const QString &path, pathList ) {
+  Q_FOREACH ( const QString &path, pathList ) {
     QFileSystemWatcher *watcher = new QFileSystemWatcher( this );
     watcher->addPath( path );
 
@@ -122,7 +122,7 @@ void AgentManager::continueStartup()
 #endif
 
   load();
-  foreach ( const AgentType &info, mAgents )
+  Q_FOREACH ( const AgentType &info, mAgents )
     ensureAutoStart( info );
 
   // register the real service name once everything is up an running
@@ -141,7 +141,7 @@ AgentManager::~AgentManager()
 
 void AgentManager::cleanup()
 {
-  foreach ( const AgentInstance::Ptr &instance, mAgentInstances )
+  Q_FOREACH ( const AgentInstance::Ptr &instance, mAgentInstances )
     instance->quit();
 
   mAgentInstances.clear();
@@ -298,13 +298,13 @@ void AgentManager::removeAgentInstance( const QString &identifier )
   preProcessorManager.unregisterInstance( instance->identifier() );
 
   if ( instance->hasAgentInterface() ) {
-    qDebug() << "AgentManager::removeAgentInstance: calling instance->quit()";
+    akDebug() << "AgentManager::removeAgentInstance: calling instance->quit()";
     instance->quit();
   } else {
     akError() << Q_FUNC_INFO << "Agent instance" << identifier << "has no interface!";
   }
 
-  emit agentInstanceRemoved( identifier );
+  Q_EMIT agentInstanceRemoved( identifier );
 }
 
 QString AgentManager::agentInstanceType( const QString &identifier )
@@ -444,14 +444,14 @@ void AgentManager::updatePluginInfos()
   const QHash<QString, AgentType> oldInfos = mAgents;
   readPluginInfos();
 
-  foreach ( const AgentType &oldInfo, oldInfos ) {
+  Q_FOREACH ( const AgentType &oldInfo, oldInfos ) {
     if ( !mAgents.contains( oldInfo.identifier ) )
-      emit agentTypeRemoved( oldInfo.identifier );
+      Q_EMIT agentTypeRemoved( oldInfo.identifier );
   }
 
-  foreach ( const AgentType &newInfo, mAgents ) {
+  Q_FOREACH ( const AgentType &newInfo, mAgents ) {
     if ( !oldInfos.contains( newInfo.identifier ) ) {
-      emit agentTypeAdded( newInfo.identifier );
+      Q_EMIT agentTypeAdded( newInfo.identifier );
       ensureAutoStart( newInfo );
     }
   }
@@ -467,7 +467,7 @@ void AgentManager::readPluginInfos()
 
   const QStringList pathList = pluginInfoPathList();
 
-  foreach ( const QString &path, pathList ) {
+  Q_FOREACH ( const QString &path, pathList ) {
       const QDir directory( path, QLatin1String("*.desktop") );
       readPluginInfos( directory );
   }
@@ -476,8 +476,8 @@ void AgentManager::readPluginInfos()
 void AgentManager::readPluginInfos( const QDir &directory )
 {
   const QStringList files = directory.entryList();
-  qDebug() << "PLUGINS: " << directory.canonicalPath();
-  qDebug() << "PLUGINS: " << files;
+  akDebug() << "PLUGINS: " << directory.canonicalPath();
+  akDebug() << "PLUGINS: " << files;
   for ( int i = 0; i < files.count(); ++i ) {
     const QString fileName = directory.absoluteFilePath( files[ i ] );
 
@@ -490,7 +490,7 @@ void AgentManager::readPluginInfos( const QDir &directory )
 
       const QString disableAutostart = getEnv( "AKONADI_DISABLE_AGENT_AUTOSTART" );
       if ( !disableAutostart.isEmpty() ) {
-        qDebug() << "Autostarting of agents is disabled.";
+        akDebug() << "Autostarting of agents is disabled.";
         agentInfo.capabilities.removeOne( AgentType::CapabilityAutostart );
       }
 
@@ -509,7 +509,7 @@ void AgentManager::readPluginInfos( const QDir &directory )
 #endif
       }
 
-      qDebug() << "PLUGINS inserting: " << agentInfo.identifier << agentInfo.instanceCounter << agentInfo.capabilities;
+      akDebug() << "PLUGINS inserting: " << agentInfo.identifier << agentInfo.instanceCounter << agentInfo.capabilities;
       mAgents.insert( agentInfo.identifier, agentInfo );
     }
   }
@@ -567,12 +567,12 @@ void AgentManager::save()
 {
   QSettings file( AkStandardDirs::agentConfigFile( Akonadi::XdgBaseDirs::WriteOnly ), QSettings::IniFormat );
 
-  foreach ( const AgentType &info, mAgents )
+  Q_FOREACH ( const AgentType &info, mAgents )
     info.save( &file );
 
   file.beginGroup( QLatin1String("Instances") );
   file.remove( QString() );
-  foreach ( const AgentInstance::Ptr &instance, mAgentInstances ) {
+  Q_FOREACH ( const AgentInstance::Ptr &instance, mAgentInstances ) {
     file.beginGroup( instance->identifier() );
     file.setValue( QLatin1String("AgentType"), instance->agentType() );
     file.endGroup();
@@ -588,7 +588,7 @@ void AgentManager::serviceOwnerChanged( const QString &name, const QString&, con
   // This is called by the D-Bus server when a service comes up, goes down or changes ownership for some reason
   // and this is where we "hook up" our different Agent interfaces.
 
-  //qDebug() << "Service " << name << " owner changed from " << oldOwner << " to " << newOwner;
+  //akDebug() << "Service " << name << " owner changed from " << oldOwner << " to " << newOwner;
 
   if ( (name == AkDBus::serviceName(AkDBus::Server) || name == AkDBus::serviceName(AkDBus::AgentServer)) && !newOwner.isEmpty() ) {
     if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::Server) )
@@ -617,7 +617,7 @@ void AgentManager::serviceOwnerChanged( const QString &name, const QString&, con
         return;
 
       if ( !restarting )
-        emit agentInstanceAdded( agentIdentifier );
+        Q_EMIT agentInstanceAdded( agentIdentifier );
 
       break;
     }
@@ -649,10 +649,10 @@ void AgentManager::serviceOwnerChanged( const QString &name, const QString&, con
       // The order of interface deletions depends on Qt but we handle both cases.
 
       // Check if we "know" about it.
-      qDebug() << "Preprocessor " << agentIdentifier << " is going up or down...";
+      akDebug() << "Preprocessor " << agentIdentifier << " is going up or down...";
 
       if ( !mAgentInstances.contains( agentIdentifier ) ) {
-        qDebug() << "But it isn't registered as agent... not mine (anymore?)";
+        akDebug() << "But it isn't registered as agent... not mine (anymore?)";
         return; // not our agent (?)
       }
 
@@ -664,7 +664,7 @@ void AgentManager::serviceOwnerChanged( const QString &name, const QString&, con
         );
 
       if ( !preProcessorManager.isValid() ) {
-        akError() << Q_FUNC_INFO <<"Could not connect to PreprocessorManager via D-Bus:" << preProcessorManager.lastError();
+        akError() << Q_FUNC_INFO <<"Could not connect to PreprocessorManager via D-Bus:" << preProcessorManager.lastError().message();
       } else {
         if ( newOwner.isEmpty() ) {
           // The preprocessor went down. Unregister it on server side.
@@ -678,13 +678,13 @@ void AgentManager::serviceOwnerChanged( const QString &name, const QString&, con
           if ( !mAgentInstances.value( agentIdentifier )->obtainPreprocessorInterface() ) {
             // Hm.. couldn't hook up its preprocessor interface..
             // Make sure we don't have it in the preprocessor chain
-            qWarning() << "Couldn't obtain preprocessor interface for instance " << agentIdentifier;
+            qWarning() << "Couldn't obtain preprocessor interface for instance" << agentIdentifier;
 
             preProcessorManager.unregisterInstance( agentIdentifier );
             return;
           }
 
-          qDebug() << "Registering preprocessor instance " << agentIdentifier;
+          akDebug() << "Registering preprocessor instance" << agentIdentifier;
 
           // Add to the preprocessor chain
           preProcessorManager.registerInstance( agentIdentifier );
@@ -774,9 +774,9 @@ void AgentManager::agentExeChanged( const QString &fileName )
   if ( !QFile::exists( fileName ) )
     return;
 
-  foreach ( const AgentType &type, mAgents ) {
+  Q_FOREACH ( const AgentType &type, mAgents ) {
     if ( fileName.endsWith( type.exec ) ) {
-      foreach ( const AgentInstance::Ptr &instance, mAgentInstances ) {
+      Q_FOREACH ( const AgentInstance::Ptr &instance, mAgentInstances ) {
         if ( instance->agentType() == type.identifier )
           instance->restartWhenIdle();
       }
@@ -798,8 +798,8 @@ void AgentManager::registerAgentAtServer( const QString &agentIdentifier, const
 
 void AgentManager::addSearch( const QString &query, const QString &queryLanguage, qint64 resultCollectionId )
 {
-  qDebug() << "AgentManager::addSearch" << query << queryLanguage << resultCollectionId;
-  foreach ( const AgentInstance::Ptr &instance, mAgentInstances ) {
+  akDebug() << "AgentManager::addSearch" << query << queryLanguage << resultCollectionId;
+  Q_FOREACH ( const AgentInstance::Ptr &instance, mAgentInstances ) {
     const AgentType type = mAgents.value( instance->agentType() );
     if ( type.capabilities.contains( AgentType::CapabilitySearch ) && instance->searchInterface() )
       instance->searchInterface()->addSearch( query, queryLanguage, resultCollectionId );
@@ -808,8 +808,8 @@ void AgentManager::addSearch( const QString &query, const QString &queryLanguage
 
 void AgentManager::removeSearch( quint64 resultCollectionId )
 {
-  qDebug() << "AgentManager::removeSearch" << resultCollectionId;
-  foreach ( const AgentInstance::Ptr &instance, mAgentInstances ) {
+  akDebug() << "AgentManager::removeSearch" << resultCollectionId;
+  Q_FOREACH ( const AgentInstance::Ptr &instance, mAgentInstances ) {
     const AgentType type = mAgents.value( instance->agentType() );
     if ( type.capabilities.contains( AgentType::CapabilitySearch ) && instance->searchInterface() )
       instance->searchInterface()->removeSearch( resultCollectionId );
@@ -818,7 +818,7 @@ void AgentManager::removeSearch( quint64 resultCollectionId )
 
 void AgentManager::agentServerFailure()
 {
-  qDebug() << "Failed to start AgentServer!";
+  akError() << "Failed to start AgentServer!";
   // if ( requiresAgentServer )
   //   QCoreApplication::instance()->exit( 255 );
 }
