@@ -19,6 +19,7 @@
 */
 
 #include "notificationmanager.h"
+#include <akdebug.h>
 #include "notificationmanageradaptor.h"
 #include "notificationsource.h"
 #include "tracer.h"
@@ -75,7 +76,7 @@ void NotificationManager::connectNotificationCollector(NotificationCollector* co
 
 void NotificationManager::slotNotify(const Akonadi::NotificationMessage::List &msgs)
 {
-  foreach ( const NotificationMessage &msg, msgs )
+  Q_FOREACH ( const NotificationMessage &msg, msgs )
     NotificationMessage::appendAndCompress( mNotifications, msg );
   if ( !mTimer.isActive() )
     mTimer.start();
@@ -85,7 +86,7 @@ void NotificationManager::emitPendingNotifications()
 {
   if ( mNotifications.isEmpty() )
     return;
-  foreach ( const NotificationMessage &msg, mNotifications ) {
+  Q_FOREACH ( const NotificationMessage &msg, mNotifications ) {
     Tracer::self()->signal( "NotificationManager::notify", msg.toString() );
   }
 
@@ -94,7 +95,7 @@ void NotificationManager::emitPendingNotifications()
   }
 
   // backward compatibility with the old non-subcription interface
-  emit notify( mNotifications );
+  Q_EMIT notify( mNotifications );
 
   mNotifications.clear();
 }
@@ -106,7 +107,7 @@ QDBusObjectPath NotificationManager::subscribe( const QString &identifier )
   NotificationSource *source = mNotificationSources.value( identifier );
   if ( source ) {
     // :TODO: Should this really be a warning?
-    qDebug() << "Known subscriber" << identifier << "subscribes again";
+    akDebug() << "Known subscriber" << identifier << "subscribes again";
     source->addClientServiceName( message().service() );
   } else {
     source = new NotificationSource( identifier, message().service(), this );
@@ -123,7 +124,7 @@ void NotificationManager::unsubscribe( const QString &identifier )
   if ( source ) {
     source->deleteLater();
   } else {
-    qDebug() << "Attempt to unsubscribe unknown subscriber" << identifier;
+    akDebug() << "Attempt to unsubscribe unknown subscriber" << identifier;
   }
 }
 
