@@ -29,7 +29,7 @@
 class AkStandardDirsTest : public QObject
 {
   Q_OBJECT
-  private slots:
+  private Q_SLOTS:
     void testCondigFile()
     {
       akTestSetInstanceIdentifier( QString() );
